@@ -44,7 +44,7 @@ class HttpClient(object):
     endpoint = None
 
     def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION, cert=None):
-        self.tls_version = tls_version
+        self._tls_version = tls_version
         self.cert = cert
 
     def __enter__(self):
@@ -71,7 +71,7 @@ class HttpClient(object):
         log.debug("Request is: %s", cmd_url)
 
         self._tls_session = Session()
-        self._tls_session.mount("http://", UseTlsAdapter(self.tls_version))
+        self._tls_session.mount("http://", UseTlsAdapter(self._tls_version))
 
         try:
             if file is not None:
@@ -176,6 +176,7 @@ class LoadMaster(HttpClient):
         return {
             "endpoint": self.endpoint,
             "ip_address": self.ip_address,
+            "cert": self.cert,
         }
 
     @property
@@ -369,7 +370,8 @@ class LoadMaster(HttpClient):
                                                            port=self.port)
         try:
             self._tls_session = Session()
-            self._tls_session.mount("http://", UseTlsAdapter(self.tls_version))
+            self._tls_session.mount("http://",
+                                    UseTlsAdapter(self._tls_version))
             if self.cert:
                 self._tls_session.get(url, verify=False, timeout=1,
                                       cert=self.cert)
@@ -551,7 +553,7 @@ class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
     _API_IGNORE = (
         "ip_address", "endpoint", "rsindex", "vsindex", "index", "status",
-        "subvs_data", "subvs_entries", "real_servers",
+        "subvs_data", "subvs_entries", "real_servers", "cert",
     )
 
     def __repr__(self):
@@ -614,6 +616,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             self.index = ip_or_index
             self.vs = ip_or_index
 
+        self.cert = loadmaster_info.get("cert")
         try:
             self.endpoint = loadmaster_info["endpoint"]
         except KeyError:
@@ -656,6 +659,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         if self.index is None:
             return {
                 "endpoint": self.endpoint,
+                "cert": self.cert,
                 "ip_address": self.ip_address,
                 "vs": self.vs,
                 "port": self.port,
@@ -664,6 +668,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         else:
             return {
                 "endpoint": self.endpoint,
+                "cert": self.cert,
                 "ip_address": self.ip_address,
                 "vs": self.index,
             }
@@ -798,6 +803,7 @@ class RealServer(HttpClient, KempBaseObjectModel):
         validate_ip(ip)
         self.rsport = port
         validate_port(port)
+        self.cert = loadmaster_virt_service_info.get("cert")
         try:
             self.vs = loadmaster_virt_service_info["vs"]
         except KeyError:
