@@ -48,7 +48,8 @@ class UnauthorizedAccessError(KempTechApiException):
     def __init__(self, cmd_url, code=None):
         msg = "You do not have authorized access to {}. " \
               "Please check your credentials.".format(cmd_url)
-        super(UnauthorizedAccessError, self).__init__(msg, code=code)
+        super(UnauthorizedAccessError, self).__init__(msg, code=code,
+                                                      is_xml_msg=False)
 
 
 class UrlRequiredError(KempTechApiException):
